@@ -1,3 +1,4 @@
+import pickle
 from io import BytesIO
 
 import pandas as pd
@@ -31,12 +32,8 @@ class SeriesField(BaseField):
 class FrameField(BaseField):
     def __set__(self, instance, value):
         # convert the incoming series into a json document
-        if value is not None:
-            # check it's really a DataFrame
-            if not isinstance(value, str):
-                assert isinstance(value, pd.DataFrame)
-                # convert the frame into a json string
-                value = value.to_json(orient="table")
+        if isinstance(value, pd.DataFrame):
+            value = value.to_json(orient="table")
 
         # give the (new) value to mum
         super(FrameField, self).__set__(instance, value)
@@ -58,15 +55,12 @@ class ParquetFrameField(BaseField):
         self.compression = compression
 
     def __set__(self, instance, value):
-        # convert the incoming series into a json document
-        if value is not None:
-            # check it's really a DataFrame
-            if not isinstance(value, str):
-                assert isinstance(value, pd.DataFrame)
-                # convert the frame into a json string
-                with BytesIO() as buffer:
-                    value.to_parquet(buffer, engine=self.engine, compression=self.compression)
-                    value = buffer.getvalue()
+        # convert the incoming series into a byte-stream document
+        if isinstance(value, pd.DataFrame):
+            # convert the frame into a json string
+            with BytesIO() as buffer:
+                value.to_parquet(buffer, engine=self.engine, compression=self.compression)
+                value = buffer.getvalue()
 
         # give the (new) value to mum
         super(ParquetFrameField, self).__set__(instance, value)
@@ -82,6 +76,31 @@ class ParquetFrameField(BaseField):
         return None
 
 
+class PickleFrameField(BaseField):
+    def __init__(self, **kwargs):
+        super().__init__(**kwargs)
+
+    def __set__(self, instance, value):
+        # convert the incoming series into a byte-stream document
+        if isinstance(value, pd.DataFrame):
+            # convert the frame into a bytestream
+            value = pickle.dumps(value)
+
+        # give the (new) value to mum
+        super(PickleFrameField, self).__set__(instance, value)
+
+    def __get__(self, instance, owner):
+        # ask mum for the value stored
+        x = super(PickleFrameField, self).__get__(instance, owner)
+
+        if x is not None:
+            with BytesIO(x) as buffer:
+                return pd.read_pickle(buffer)
+
+        return None
+
+
+
 # class OhlcField(FrameField):
 #     def __set__(self, instance, value):
 #         if isinstance(value, pd.DataFrame):
